# packetmq
packet-based message-framing network library built with Twisted

[![Documentation Status](http://readthedocs.org/projects/packetmq/badge/?version=latest)](http://packetmq.readthedocs.org/en/latest/?badge=latest)
[![Code Health](https://landscape.io/github/not-na/packetmq/master/landscape.svg?style=flat)](https://landscape.io/github/not-na/packetmq/master)
[![Coverage Status](https://coveralls.io/repos/not-na/packetmq/badge.svg?branch=master&service=github)](https://coveralls.io/github/not-na/packetmq?branch=master)
[![Build Status](https://travis-ci.org/not-na/packetmq.svg?branch=master)](https://travis-ci.org/not-na/packetmq)

## Installing

Installing through the Python Package Index:

    $ sudo pip install packetmq
OR

    $ sudo easy_install packetmq

### Requirements

* twisted >= 15.4.0
* u-msgpack-python >=2.1
* bidict>=0.9.0.post1
* Python 2.7.x
